# Copyright 2013-2021 Lawrence Livermore National Security, LLC and other
# Spack Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

from spack import *


class PyPynn(PythonPackage):
    """A Python package for simulator-independent specification of neuronal
        network models
    """

    homepage = "http://neuralensemble.org/PyNN/"
    pypi = "PyNN/PyNN-0.10.0.tar.gz"
    git = "https://github.com/NeuralEnsemble/PyNN.git"

    version('0.10.1', sha256='03fbafeddd64ae7163e2b557b2760380b6eceb52469f1b3f4cc203bbb80f0cde')
    version('0.10.0', sha256='04120fe0e03260d664b337e0ac29d985c3fb3684ef35b1add93a66739891c98f')
    version('0.9.6', sha256='d85226800e30bc1692d3f84485c3fa20b921c2ab55f1201d0a3bf23432e16cd2')
    version('0.9.5', sha256='91af2126b639a6a795bfc2709ac49423278c4794b6d0da143908b9afcb415f80')

    variant('mpi', default=False, description='Enable MPI support')
    depends_on('python@2.7:2.8,3.3:', when="@0.9.5")
    depends_on('python@2.7:2.8,3.6:', when="@0.9.6")
    depends_on('python@3.7:',         when="@0.10.0:")

    depends_on('py-setuptools',         type=('build'))

    depends_on('py-jinja2@2.7:',        type=('build', 'run'))
    depends_on('py-docutils@0.10:',     type=('build', 'run'))

    depends_on('py-numpy@1.8.2:',       type=('build', 'run'), when="@0.9.5")
    depends_on('py-numpy@1.13.0:',      type=('build', 'run'), when="@0.9.6")
    depends_on('py-numpy@1.16.1:',      type=('build', 'run'), when="@0.10.0")
    depends_on('py-numpy@1.18.5:',      type=('build', 'run'), when="@0.10.1:")

    depends_on('py-mpi4py', type=('build', 'run'), when='+mpi')
    depends_on('py-quantities@0.12.1:', type=('build', 'run'), when="@0.9.5:")

    depends_on('py-lazyarray@0.3.2:',   type=('build', 'run'), when="@0.9.5")
    depends_on('py-lazyarray@0.3.4:',   type=('build', 'run'), when="@0.9.6")
    depends_on('py-lazyarray@0.5.0:',   type=('build', 'run'), when="@0.10.0")
    depends_on('py-lazyarray@0.5.2:',   type=('build', 'run'), when="@0.10.1:")

    depends_on('py-neo@0.5.2:',         type=('build', 'run'), when="@0.9.5")
    depends_on('py-neo@0.8.0',          type=('build', 'run'), when="@0.9.6")
    depends_on('py-neo@0.10.0:',        type=('build', 'run'), when="@0.10.0")
    depends_on('py-neo@0.11.0:',        type=('build', 'run'), when="@0.10.1:")

    depends_on('neuron@8.1:',           type=('build','run'), when="@0.10.1:")
    depends_on('nest@3.3:',             type=('build','run'), when="@0.10.1:")
    depends_on('py-brian2',             type=('build','run'))

    depends_on('py-mock@1.0:', type='test')

    patch('pynn-0.9.6-python3.patch', when='@0.9.6 ^python@3:')

    # neuroml and nineml are optional dependencies. Leave out of import_modules to avoid errors in tests
    skip_modules = ['pyNN.neuroml', 'pyNN.nineml']
